globalVariables(c(".PATH_IQRreport",".COMPLIANCE_MODE"))

loadSetupOptions_IQReportAPI <- function() {
  source(system.file("setup_options_IQReportAPI.R", package="IQReportAPI"))
  if (.ALLOW_USER_SETTINGS_FILE) {
    home__ <- Sys.getenv("HOME")
    file__ <- paste0(home__,"/setup_options_IQReportAPI.R")
    if (file.exists(file__)) {
      source(file__)
    }
  }
}

.onAttach <- function(libname, pkgname) {
  packageStartupMessage(paste0("IQReportAPI: Microsoft Word reporting made simple & efficient. Enjoy!"))
}

.onLoad <- function(libname, pkgname) {
}

.onUnload <- function(libpath) {
}

aux_strrep <- function(origstr,oldsubstr,newsubstr) {
  return(gsub(oldsubstr, newsubstr, origstr, fixed="TRUE"))
}

aux_fileparts <- function(filename.with.path){
  pathname <- dirname(filename.with.path)
  filename <- basename(filename.with.path)
  fileext <- gsub(".*(\\.[^\\.]*)$","\\1",filename)
  filename <- gsub("(.*)(\\.[^\\.]*)$","\\1",filename)
  for (k in seq_along(filename)) {
    if(fileext[k]==filename[k]) fileext[k] <- ""
  }
  return(list(pathname=pathname,filename=filename,fileext=fileext))
}

aux_filewrite <- function(text,filename) {
  if (is.null(filename)) return(0)
  fid <- aux_fopen(filename, mode="w")
  write(text, fid)
  aux_fclose(fid)
}

aux_mkdir <- function(pathdir) {
  suppressWarnings(if (!file.exists(pathdir)) dir.create(pathdir,recursive='TRUE'))
}

aux_rmdir <- function(pathdir) {
  unlink(pathdir,recursive = 'TRUE')
}

aux_fopen <- function(filename,mode="w") {
  if (mode=="w") aux_mkdir(aux_fileparts(filename)$pathname)
  fid <- file(filename,open=mode)
  return(fid)
}

aux_fclose <- function(fid) {
  close(fid)
}

aux_postFillChar <- function(value2postfill,lengthString,fillChar) {
  result <- tryCatch({
    paste0(c(as.character(value2postfill)),
                   paste0(rep(fillChar,lengthString-nchar(as.character(value2postfill))),collapse=""),
                   collapse="")
  }, error = function (msg) {
    result
  })
  return(result)
}

aux_fileread <- function(filename,collapserows=TRUE) {
  fid <- aux_fopen(filename, mode="r")
  text <- readLines(fid)
  aux_fclose(fid)
  if (collapserows) {
    text <- paste(text,collapse="\n")
  }
  return(text)
}

aux_getOS <- function(){
  i <- Sys.info()[["sysname"]]
  if (i=="Windows") return("windows")
  if (i=="Darwin") return("mac")
  if (i=="Linux") return("unix")
  stop("Unknown operating system")
}

aux_closePDFs <- function() {
  tryCatch({
    mydevs <- grDevices::dev.list()
    dummy <- sapply(mydevs[names(mydevs) %in% c("pdf")], function (x) {
      grDevices::dev.off(x)
    })
  },error=function(x){})
  return(invisible(NULL))
}

aux_closePNGs <- function() {
  if (aux_getOS()=="mac") {
    grDevices::dev.off()
    return(invisible(NULL))
  }
  tryCatch({
    mydevs <- grDevices::dev.list()
    dummy <- sapply(mydevs[names(mydevs) %in% c("png")], function (x) {
      grDevices::dev.off(x)
    })
  },error=function(x){})
  return(invisible(NULL))
}

aux_strFindAll <- function(input,searchString) {
  x      <- gregexpr(pattern=searchString,input,fixed=TRUE)
  start  <- unlist(x)
  end <- start+attr(x[[1]],"match.length")-1
  if (length(start)==1 && start==-1)
    return(list(start=NULL,end=NULL))
  else
    return(list(start=start,end=end))
}

aux_strtrim <- function(input) {
  return(gsub("^\\s+|\\s+$", "", input))
}

aux_explode <- function(input,separator=",") {
  return(unlist(strsplit(input,separator)))
}

aux_explodePC <- function(input,separator=",",group="round") {
  if (group=="round") {
    groupStart__ <- "("
    groupEnd__   <- ")"
  }
  if (group=="square") {
    groupStart__ <- "["
    groupEnd__   <- "]"
  }
  if (group=="curly") {
    groupStart__ <- "{"
    groupEnd__   <- "}"
  }
  if (group!="round" & group!="square" & group!="curly") stop("wrong group definition")
  elements        <- c()
  openParenthesis <- 0
  lastIndex       <- 1
  elementIndex    <- 1
  for (k2 in 1:nchar(input)) {
    if (substr(input,k2,k2) == groupStart__) {
      openParenthesis <- openParenthesis + 1
    } else {
      if (substr(input,k2,k2) == groupEnd__) {
        openParenthesis <- openParenthesis - 1;
      } else {
        if ((substr(input,k2,k2) == separator) & (openParenthesis == 0)) {
          elements[elementIndex] <- aux_strtrim(substr(input,lastIndex,k2-1))
          elementIndex           <- elementIndex + 1
          lastIndex              <- k2+1
        }
      }
    }
  }
  elements[elementIndex] <- aux_strtrim(substr(input,lastIndex,nchar(input)))
  return(elements)
}

#' Opening the setup_options_IQReportAPI.R file for editing
#'
#' This function opens the setup_options_IQReportAPI.R for editing options.
#' The user can choose to edit the general / global settings file in the packages
#' installation location or create/edit such a file in the users home folder.
#' On cluster installations a user might not be able to change the global file and
#' in such a case the use of a users file might be useful.
#' Note that the users setup_options_IQReportAPI.R file does not need to include all
#' information present in the global setup_options_IQReportAPI.R file. The user file
#' can be used to override one or more of the settings in the global file.
#' In the setup_options_IQReportAPI.R file located in the package installation folder
#' it can be decided if such a user defined settings file is allowed or not.
#'
#' @param local Logical. If FALSE then the function will open the global file for
#'   editing. If TRUE then the function will open the local file for editing. If
#'   the local file is not present then it will be created. If the definition of
#'   a local file is disabled in the global settings file, the local=TRUE setting
#'   will lead to an error.
#'
#' @export
setup_IQReportAPI <- function(local=FALSE){
  if (!local) {
    file.edit(system.file(package="IQReportAPI","setup_options_IQReportAPI.R"))
  } else {
    loadSetupOptions_IQReportAPI()
    if (!.ALLOW_USER_SETTINGS_FILE) {
      stop("The use of a local setup_options_IQReportAPI.R file has been disabled")
    }
    home__ <- Sys.getenv("HOME")
    file__ <- paste0(home__,"/setup_options_IQReportAPI.R")
    file.edit(file__)
  }
}
